#
# spec file for package normaliz
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           normaliz
%define lname	libnormaliz3
Version:        3.9.4
Release:        1.6
Summary:        Tools for computations in affine monoids and rational cones
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.normaliz.uni-osnabrueck.de/

Source:         https://github.com/Normaliz/Normaliz/releases/download/v%version/%name-%version.tar.gz
BuildRequires:  e-antic-devel >= 1.0.1
BuildRequires:  flint-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel

%description
Normaliz is a tool for computations in affine monoids, vector configurations,
lattice polytopes, and rational cones. It supports,

* convex hulls and dual cones
* conversion from generators to constraints and vice versa
* triangulations, disjoint decompositions and Stanley decompositions
* Hilbert basis of rational, not necessarily pointed cones
* normalization of affine monoids
* lattice points of rational polytopes and (unbounded) polyhedra
* Hilbert (or Ehrhart) series and (quasi) polynomials under
  Z-gradings (for example, for rational polytopes)
* generalized (or weighted) Ehrhart series and Lebesgue integrals of
  polynomials over rational polytopes via NmzIntegrate

%package -n %lname
Summary:        C++ API for Normaliz, a tool for computation of rotational cones
Group:          System/Libraries

%description -n %lname
Normaliz is a tool for computations in affine monoids, vector configurations,
lattice polytopes, and rational cones.

Normaliz offers an API, libnormaliz, that allows the user to access
the Normaliz computations from C++ programs.

%package devel
Summary:        Development files for Normaliz, a tool for computation of rotational cones
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       gmp-devel

%description devel
Normaliz is a tool for computations in affine monoids, vector configurations,
lattice polytopes, and rational cones.

Normaliz offers an API, libnormaliz, that allows the user to access
the Normaliz computations from C++ programs.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/normaliz
%license COPYING
%doc doc/*.pdf

%files -n %lname
%_libdir/libnormaliz.so.3*

%files devel
%_includedir/libnormaliz/
%_libdir/libnormaliz.so

%changelog
* Thu Aug 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9.4
  * New: A variant of project-and-lift for "positive systems",
    i.e. diophantine linear systems whose solutions are
    nonnegative and for which Normaliz can derive upper bounds
    for all coordinates directly from the input inequalities and
    equations.
  * Lattice points in polytopes can be constrained by polynomial
    equations and inequalities.
* Wed Apr 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9.3
  * Build system updates
  * New reference manual, NmzShortRef.pdf
- Ship documentation.
* Mon Feb  7 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9.2
  * It is now possible to construct a cone in libnormaliz or
    PyNormaliz from an input file, and input files now allow the
    definition of sparse vectors with ranges of indices.
* Wed Sep  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9.1
  * This simplifies the handling of distributed computations in
    connection with volume by signed decomposition. There are a
    few other improvements.
* Fri Jul  2 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.9.0
  * Normaliz now uses e-antic for algebraic polyhedra.
  * Added the Lawrence algorithm for polytope volumes by signed
    decomposition into simplices.
  * The descent algorithm for volumes now has a variant exploiting
    isomorphisms of faces.
* Thu Feb 11 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.10
  * New data structure for the return of triangulations and other
    decompositions by libnormaliz.
* Fri Oct  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.9
  * New extensions:
  * Input types rational_lattice and rational_offset. They allow
    to choose an arbitrary sublattice of the rational space as
    the lattice of reference.
  * Computation goal IsEmptySemiOpen. It allows to check the
    emptyness of semiopen polyhedra defined by inequalities
    and strict inequalities.
  * Computation goals DualFaceLattice, DualFVector, DualIncidence
    computing the face lattice etc. for the dual cone.
  * Computation goal TriangulationGenerators: it replaces
    unstable Generators, and the name says explicitly for what it
    is meant.
* Tue Sep  1 2020 Jan Engelhardt <jengelh@inai.de>
- Enable flint integration
* Sat Aug 29 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.8
  * No user-visible changes; a build fix for Debian packaging.
* Fri Jul 31 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.7
  * It is now possible to check the emptyness of semiopen
    polyhedra via the new computation goal IsEmptySemiopen. The
    '"open faces" are defined by excluded_faces and
    inhom_excluded_faces.
* Fri Jun  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.5
  * New feature: computation of refined triangulations using all
    input generators or all lattice points in a polytope or being
    unimodular.
* Fri Feb 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.4
  * Use of precomputed data newly designed.
  * New versions of CoCoALib and nauty integrated.
* Tue Nov 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.3
  * Technical realease that fixes an incompatibility between
    libnormaliz and PyNormaliz in version 3.8.2.
* Sun Nov 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.2
  * Some improvement in convex hull computation for algebraic
    polytopes.
  * Code cleaned up and formatted; also in the installation files.
* Sun Sep 29 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.1
  * This release fixes the codimension bug of 3.8.0.
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.8.0
  * This release adds the computation of automorphism groups to
    Normaliz. Various types of automorphism groups can be
    computed: combinatorial, rational/algebraic, integral and
    euclidean. It is not yet possible to use the automorphism
    groups in the computation of other invariants, which is the
    main reason for their introduction.
- Remove 0001-Fix-a-bunch-of-compiler-warnings-and-two-actual-bugs.patch,
  headerfile.patch
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Add headerfile.patch to provide normaliz/output.h.
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.7.4
  * Algebraic polyhedra: these can now be computed directly in
    Normaliz so that QNormaliz has become obsolete.
  * Face lattice and f-vector can now be computed by Normaliz.
  * NumberLatticePoints is a new computation goal that lets
    Normaliz count lattice points in polytopes without storing
    them.
  * Added the computation goals Dynamic and Static and the
    libnormaliz function modifyCone.
- Add 0001-Fix-a-bunch-of-compiler-warnings-and-two-actual-bugs.patch
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 3.6.3:
  * Fix configure.ac that caused building issues.
- Update to version 3.6.2:
  * Fix problems with certain borderline input, like empty
    polytopes or polytopes of embedding dimension 0.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 3.6.1:
  * Introduction of NoGradingDenom and better treatment of
    polytopes.
  * Refinements in the computation of volumes.
* Sat Jun  9 2018 badshah400@gmail.com
- Update to version 3.6.0:
  * Includes QNormaliz as a tool for algebraic polyhedra and its
    Python interface PyQNormaliz.
  * The install scripts have been revised thoroughly.
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 3.5.4:
  * Make computations that so far required homogeneous input
    available to all polytopes, regardless of the input type:
    Ehrhart series, triangulations, cone decomposition, Stanley
    decomposition.
- Changes from version 3.5.3:
  * Performance improvements.
  * Bug fixes.
- Changes from version 3.5.2:
  * Introduce a new algorithm for volume computations by descent
    in the face lattice.
  * Bug fixes.
- Use %%%%license to package COPYING file, instead of %%%%doc.
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 3.5.1:
  * Uniqueness in output of not uniqely determined results (bases
    of sublattices, equations), necessary to make all tests yield
    the same results on all.
  systems
- Drop 0001-Fix-compiler-warnings-in-matrix.cpp.patch:
  incorporated upstream.
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 3.5.0
  * Euclidean volume of polytopes
  * Expansion of series
  * Projection of cones and polyhedra
  * LLL reduced coordinates for project-and-lift
- Add 0001-Fix-compiler-warnings-in-matrix.cpp.patch
* Wed Nov 22 2017 badshah400@gmail.com
- Update to version 3.4.1:
  * Miscellaneous bug fixes.
* Wed Sep 27 2017 jengelh@inai.de
- Let normaliz-devel require boost-devel because its
  header files do.
* Mon Sep 25 2017 jengelh@inai.de
- Drop unusual Require on gap-core (copy&paste error?)
* Sat Aug 26 2017 badshah400@gmail.com
- Update to version 3.4.0:
  * New project-and-lift algorithm, also in a floating point
    variant.
  * Improved subdivision of large simplicial cones, equivalent own
    replacement of Scip.
  * Floating point input (and, partly, output).
  * Fast Gorenstein test.
  * Restriction of number of significant coefficients of
    quasipolynomial.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to new upstream release 3.3.0:
  * Inclusion of NmzIntegrate in libnormaliz
  * Rational numbers in input
  * Improvement of polynomial arithmetic
  * Controlled interruption
* Thu Mar 23 2017 jengelh@inai.de
- Update to new upstream release 3.2.1
  * Automatic choice of symmetrization
  * better use of HSOP option via libnormaliz
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 3.2.0
  * Constriants in symbolic format
  * A better implementation of Approximate and its use in the
    inhomogeneous case
  * Option for Symmetrize that produces symmetrized input for and
    runs nmzIntegrate and runs on it
  * QNormaliz, a version of Normaliz using coordinates in an
    extension of the rational numbers (estricted to convex hull
    computations and triangulation)
  * Further automatic choices of algorithmic variants
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 3.1.1
  * support for nonpointed cones / input of subspace
  * new computation goals: IsIntegrallyClosed and
  WitnessNotIntegrallyClosed
  * new computation goal: IntegerHull
  * new computation goal: ConeDecomposition
* Sat Mar 12 2016 jengelh@inai.de
- Initial package (version 3.1.0) for build.opensuse.org
